==> haskell-th-abstraction-0.3.2.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.3.2.0
visibility:           public
id:                   th-abstraction-0.3.2.0-4yEKsz3hkum2d9EYr8unnF
key:                  th-abstraction-0.3.2.0-4yEKsz3hkum2d9EYr8unnF
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  063ae03137e91959aba12935b18a0123
exposed:              True
exposed-modules:      Language.Haskell.TH.Datatype
hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/th-abstraction-0.3.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/th-abstraction-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/th-abstraction-0.3.2.0
hs-libraries:         HSth-abstraction-0.3.2.0-4yEKsz3hkum2d9EYr8unnF
depends:
    base-4.14.0.0 containers-0.6.2.1 ghc-prim-0.6.1
    template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.3.2.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-abstraction
version:              0.3.2.0
visibility:           public
id:                   th-abstraction-0.3.2.0-JULJofFxTYI9l1bgfMo5si
key:                  th-abstraction-0.3.2.0-JULJofFxTYI9l1bgfMo5si
license:              ISC
copyright:            2017 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/th-abstraction
synopsis:             Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.

category:             Development
abi:                  9562b5cb07b56838b18cbc2bc05588ea
exposed:              True
exposed-modules:      Language.Haskell.TH.Datatype
hidden-modules:       Language.Haskell.TH.Datatype.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/th-abstraction-0.3.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/th-abstraction-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/th-abstraction-0.3.2.0
hs-libraries:         HSth-abstraction-0.3.2.0-JULJofFxTYI9l1bgfMo5si
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1
    template-haskell-2.16.0.0

haddock-interfaces:
    /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock

haddock-html:         /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
